import { Image, ScrollView, Text, View } from "@tarojs/components"
import classnames from "classnames";
import Search from '@/components/search'
import Filter from "@/components/filter";
import InfiniteScroll from '@/components/infiniteScroll'
import SortBtn from "@/components/sortBtn";
import SearchInput from "@/components/searchInput";
import LinkBlueTooth from "@/components/bluetooth/LinkBlueTooth";
import {useBluetooth} from "@/use/contextBlueTooth"
import {toRgb} from '@/common/bluetooth/color/colorSpace'
import Tabs from "@/components/tabs";
import styles  from './hightSearchList.module.scss'
import { useCallback, useEffect, useRef, useState } from "react";
import Taro, { useDidShow, usePullDownRefresh, useReady } from "@tarojs/taro";
import useManualPullDownRefresh from "@/use/useManualPullDownRefresh";
import {GetLabProductApi} from "@/api/material"
import { getFilterData } from "@/common/util";
import { formatHashTag, formatImgUrl } from "@/common/fotmat";
import LoadingCard from "@/components/loadingCard";
import useLogin from "@/use/useLogin";
import { goLink } from "@/common/common";

export default () => {
    const {checkLogin} = useLogin()
    useDidShow(async () => {
        await checkLogin()
    })

    const [showFilter, setShowFilter] = useState(false)
    const [selectList, setSelectList] = useState([
        {title: '系列', value:1},
        {title: '系列', value:2},
        {title: '系列', value:3},
        {title: '系列', value:4},
        {title: '系列', value:5},
        {title: '系列', value:5},
        {title: '系列', value:5},
        {title: '系列', value:5},
        {title: '系列', value:5},
    ])

    //搜索参数
    const [searchField, setSearchField] = useState({
        l: '',
        a: '',
        b: '',
        page : 1,
        size : 10
    })

    //获取面料列表
    const [materialList, setMaterialList] = useState<{list:any[], total:number}>({list:[], total:0})
    const {fetchData: materialFetchData, state: materialState} = GetLabProductApi()
    const getProductList = async () => {
        let {data} = await materialFetchData(getFilterData(searchField))
        setMaterialList({list:data.list, total:data.total})
        Taro.stopPullDownRefresh()
    }

    //监听筛选条件变化
    useEffect(() => {
        getProductList()
    }, [searchField])

    //上拉加载数据
    const pageNum = useRef({size: searchField.size, page: searchField.page})
    const [hasMore, setHasMore] = useState(true)
    const getScrolltolower = () => {
        if(materialList.list.length < materialList.total) {
            pageNum.current.page++
            const size = pageNum.current.size * pageNum.current.page
            setSearchField({...searchField, size })
        }
    }

     //监听获得的数据变化
     useEffect(() => {
        (materialList.list.length < materialList.total)?setHasMore(true):setHasMore(false)
    }, [materialList])


    const [scrollStatus, setScrollStatus] = useState(false)
    const onscroll = useCallback((e) => {
        if(e.detail.scrollTop > 20) {
            setScrollStatus(true)
        } else {
            setScrollStatus(false)
        }
    },[])

    const {state: colorState, measureAndGetLab} = useBluetooth()
    const getLab = () => {
        if(colorState.connected) {
            measureAndGetLab()
        } else {
            Taro.showToast({
                title: '请链接设备',
                icon: 'none'
            })
        }
    }

    const [blueToothColor, setBlueToothColor] = useState('')
    useEffect(() => {
        if(colorState.deviceLab) {
            console.log('颜色：',colorState.deviceLab)
            const rgb = toRgb([colorState.deviceLab.L, colorState.deviceLab.a, colorState.deviceLab.b])
            setBlueToothColor(`rgb(${rgb[0]}, ${rgb[1]}, ${rgb[2]})`)
            setSearchField({...searchField, l:rgb[0], a:rgb[1], b:rgb[2], size:10})
        }
    }, [colorState.deviceLab])

    const goLinkPage = (item) => {
        goLink('/pages/details/index',{id:item.id})
    }

    //页面下拉刷新
    usePullDownRefresh(() => {
        setSearchField({...searchField ,size : 10})
    })
    return (
        <View className={styles.main}>
            <View className={styles.search}>
                <View className={styles.SearchInput}>
                    <LinkBlueTooth/>
                    <SearchInput title="提取颜色" showBorder={false}>
                        <View className={styles.bluetooth_color} onClick={() => getLab()}>
                            {blueToothColor&&<View className={classnames(styles.color_bock)} style={{background:blueToothColor}}></View>||
                                <View className={classnames(styles.color_bock_no)} >请取色</View>
                            }
                        </View>
                    </SearchInput>
                </View>
            </View>
            <View className={styles.filter}>
                <View className={styles.filter_all}>
                    <View className={styles.text_zh}>
                        <Text>综合</Text>
                        <SortBtn status="top"/>
                    </View>
                    <View className={styles.text_sc} >
                        <Text>收藏</Text>
                        <SortBtn status="top"/>
                    </View>
                    
                </View>
                <View className={styles.filter_btn_con}>
                    <ScrollView scrollX className={styles.filter_scroll}>
                        <View className={styles.filter_btn}>
                                <View>系列</View>
                                <View>幅宽</View>
                                <View>克重</View>
                                <View>克重</View>
                                <View>克重</View>
                                <View className={styles.selected}>成分</View>
                        </View>
                    </ScrollView>
                    <View className={styles.filter_more} onClick={() => setShowFilter(true)}>
                        <Text>筛选</Text>
                        <Text className={classnames('iconfont icon-shaixuan', styles.miconfont)}></Text>
                    </View>
                </View>
            </View>
            <View className={styles.list}>
                <View className={classnames(styles.list_num, scrollStatus&&styles.list_num_shadow)}>搜索结果 ({materialList.total}条记录)</View>
                <View className={styles.scroll}>
                    {(materialList.list.length == 0&&materialState.loading)&&<LoadingCard/>}
                    {(materialList.list.length == 0 && !materialState.loading)&&<LoadingCard title="暂无数据" loadingIcon={false}/>}
                    {(materialList.list.length > 0)&&<InfiniteScroll 
                        selfonScrollToLower={() => getScrolltolower()} 
                        selfOnScroll={(e) => onscroll(e)}
                        hasMore={hasMore}
                    >
                        <View className={styles.product_list}>
                            {materialList.list.map(item => {
                                return <View key={item.id} className={styles.product_item} onClick={() => goLinkPage(item)}>
                                    <View className={styles.product_img}>
                                        <Image mode="aspectFill" src={formatImgUrl(item.texture_url)}></Image>
                                        <View className={styles.color_num}>{(item.product_color_code)}#</View>
                                    </View>
                                    <View className={styles.product_info}>
                                        <View className={styles.title}>{formatHashTag(item.product_code, item.product_name)}</View>
                                        <View className={styles.introduce}>{item.product_kind_name}</View>
                                    </View>
                                </View>
                            })}
                        </View>
                    </InfiniteScroll>}
                </View>
            </View>
            <Filter show={showFilter} onClose={() => setShowFilter(false)}/>
        </View>
    )
}